@@ -2,12 +2,11 @@ from fastapi import FastAPI
 from pymongo import MongoClient
 from pymongo.database import Database
 from typing import Any, TypeVar
-from pydantic import BaseModel
 
-from settings import BaseServiceSettings, MongoSettings
+from .settings import BaseServiceSettings, MongoSettings
 
 
-class WithMongo(BaseModel):
+class WithMongo:
     """
     The attributes that get added on for the Mongo Mixin
     """
